@@ -72,9 +72,11 @@ class TestIosAclsModule(TestIosModule):
             Extended IP access list 110
                 10 permit tcp 198.51.100.0 0.0.0.255 any eq 22 log (tag = testLog)
                 20 deny icmp 192.0.2.0 0.0.0.255 192.0.3.0 0.0.0.255 echo dscp ef ttl eq 10
-                30 deny icmp object-group test_network_og any echo dscp ef ttl eq 10
+                30 deny icmp object-group test_network_og any any echo dscp ef ttl eq 10
             IPv6 access list R1_TRAFFIC
                 deny tcp any eq www any eq telnet ack dscp af11 sequence 10
+            Extended IP access list test_pre
+                10 permit ip any any precedence internet
             """,
         )
         set_module_args(
@@ -83,6 +85,20 @@ class TestIosAclsModule(TestIosModule):
                     dict(
                         afi="ipv4",
                         acls=[
+                            dict(
+                                aces=[
+                                    dict(
+                                        destination=dict(any=True),
+                                        grant="permit",
+                                        precedence="immediate",
+                                        protocol="ip",
+                                        sequence=20,
+                                        source=dict(any=True),
+                                    ),
+                                ],
+                                acl_type="extended",
+                                name="test_pre",
+                            ),
                             dict(
                                 name="std_acl",
                                 acl_type="standard",
@@ -129,7 +145,7 @@ class TestIosAclsModule(TestIosModule):
                                         destination=dict(
                                             address="192.0.2.0",
                                             wildcard_bits="0.0.0.255",
-                                            port_protocol=dict(eq="www"),
+                                            port_protocol=dict(eq="80"),
                                         ),
                                         protocol="tcp",
                                         sequence=100,
@@ -159,7 +175,6 @@ class TestIosAclsModule(TestIosModule):
             ),
         )
         result = self.execute_module(changed=True)
-
         commands = [
             "ip access-list standard std_acl",
             "deny 192.0.2.0 0.0.0.255",
@@ -169,6 +184,8 @@ class TestIosAclsModule(TestIosModule):
             "ip access-list extended in_to_out",
             "permit tcp host 10.1.1.2 host 172.16.1.1 eq telnet",
             "deny ip any any log-input test_logInput",
+            "ip access-list extended test_pre",
+            "20 permit ip any any precedence immediate",
         ]
         self.assertEqual(sorted(result["commands"]), sorted(commands))
 
@@ -179,7 +196,7 @@ class TestIosAclsModule(TestIosModule):
             Extended IP access list 110
                 10 permit tcp 198.51.100.0 0.0.0.255 any eq 22 log (tag = testLog)
                 20 deny icmp 192.0.2.0 0.0.0.255 192.0.3.0 0.0.0.255 echo dscp ef ttl eq 10
-                30 deny icmp object-group test_network_og any echo dscp ef ttl eq 10
+                30 deny icmp object-group test_network_og any any echo dscp ef ttl eq 10
             IPv6 access list R1_TRAFFIC
                 deny tcp any eq www any eq telnet ack dscp af11 sequence 10
             """,
@@ -233,6 +250,7 @@ class TestIosAclsModule(TestIosModule):
                                         sequence="30",
                                         source=dict(
                                             object_group="test_network_og",
+                                            any=True,
                                         ),
                                         destination=dict(any=True),
                                         dscp="ef",
@@ -281,7 +299,7 @@ class TestIosAclsModule(TestIosModule):
             Extended IP access list 110
                 10 permit tcp 198.51.100.0 0.0.0.255 any eq 22 log (tag = testLog)
                 20 deny icmp 192.0.2.0 0.0.0.255 192.0.3.0 0.0.0.255 echo dscp ef ttl eq 10
-                30 deny icmp object-group test_network_og any echo dscp ef ttl eq 10
+                30 deny icmp object-group test_network_og any any echo dscp ef ttl eq 10
             IPv6 access list R1_TRAFFIC
                 deny tcp any eq www any eq telnet ack dscp af11 sequence 10
             ip access-list standard test_acl
@@ -347,7 +365,7 @@ class TestIosAclsModule(TestIosModule):
             Extended IP access list 110
                 10 permit tcp 198.51.100.0 0.0.0.255 any eq 22 log (tag = testLog)
                 20 deny icmp 192.0.2.0 0.0.0.255 192.0.3.0 0.0.0.255 echo dscp ef ttl eq 10
-                30 deny icmp object-group test_network_og any echo dscp ef ttl eq 10
+                30 deny icmp object-group test_network_og any any echo dscp ef ttl eq 10
             IPv6 access list R1_TRAFFIC
                 deny tcp any eq www any eq telnet ack dscp af11 sequence 10
             """,
@@ -403,6 +421,7 @@ class TestIosAclsModule(TestIosModule):
                                         sequence="30",
                                         source=dict(
                                             object_group="test_network_og",
+                                            any=True,
                                         ),
                                         destination=dict(any=True),
                                         dscp="ef",
@@ -427,7 +446,7 @@ class TestIosAclsModule(TestIosModule):
             Extended IP access list 110
                 10 permit tcp 198.51.100.0 0.0.0.255 any eq 22 log (tag = testLog)
                 20 deny icmp 192.0.2.0 0.0.0.255 192.0.3.0 0.0.0.255 echo dscp ef ttl eq 10
-                30 deny icmp object-group test_network_og any echo dscp ef ttl eq 10
+                30 deny icmp object-group test_network_og any any echo dscp ef ttl eq 10
             IPv6 access list R1_TRAFFIC
                 deny tcp any eq www any eq telnet ack dscp af11 sequence 10
             """,
@@ -484,7 +503,7 @@ class TestIosAclsModule(TestIosModule):
             Extended IP access list 110
                 10 permit tcp 198.51.100.0 0.0.0.255 any eq 22 log (tag = testLog)
                 20 deny icmp 192.0.2.0 0.0.0.255 192.0.3.0 0.0.0.255 echo dscp ef ttl eq 10
-                30 deny icmp object-group test_network_og any echo dscp ef ttl eq 10
+                30 deny icmp object-group test_network_og any any echo dscp ef ttl eq 10
             Reflexive IP access list MIRROR
                 permit tcp host 0.0.0.0 eq 22 host 192.168.0.1 eq 50200 (2 matches) (time left 123)
                 permit tcp host 0.0.0.0 eq 22 host 192.168.0.1 eq 50201 (2 matches) (time left 345)
@@ -544,6 +563,7 @@ class TestIosAclsModule(TestIosModule):
                                         sequence="30",
                                         source=dict(
                                             object_group="test_network_og",
+                                            any=True,
                                         ),
                                         destination=dict(any=True),
                                         dscp="ef",
@@ -595,7 +615,7 @@ class TestIosAclsModule(TestIosModule):
             Extended IP access list 110
                 10 permit tcp 198.51.100.0 0.0.0.255 any eq 22 log (tag = testLog)
                 20 deny icmp 192.0.2.0 0.0.0.255 192.0.3.0 0.0.0.255 echo dscp ef ttl eq 10
-                30 deny icmp object-group test_network_og any echo dscp ef ttl eq 10
+                30 deny icmp object-group test_network_og any any echo dscp ef ttl eq 10
             IPv6 access list R1_TRAFFIC
                 deny tcp any eq www any eq telnet ack dscp af11 sequence 10
             """,
@@ -615,7 +635,7 @@ class TestIosAclsModule(TestIosModule):
             Extended IP access list 110
                 10 permit tcp 198.51.100.0 0.0.0.255 any eq 22 log (tag = testLog)
                 20 deny icmp 192.0.2.0 0.0.0.255 192.0.3.0 0.0.0.255 echo dscp ef ttl eq 10
-                30 deny icmp object-group test_network_og any echo dscp ef ttl eq 10
+                30 deny icmp object-group test_network_og any any echo dscp ef ttl eq 10
             IPv6 access list R1_TRAFFIC
                 deny tcp any eq www any eq telnet ack dscp af11 sequence 10
             """,
@@ -840,7 +860,7 @@ class TestIosAclsModule(TestIosModule):
             Extended IP access list 110
                 10 permit tcp 198.51.100.0 0.0.0.255 any eq 22 log (tag = testLog)
                 20 deny icmp 192.0.2.0 0.0.0.255 192.0.3.0 0.0.0.255 echo dscp ef ttl eq 10
-                30 deny icmp object-group test_network_og any echo dscp ef ttl eq 10
+                30 deny icmp object-group test_network_og any any echo dscp ef ttl eq 10
             access-list 110 remark test ab.
             access-list 110 remark test again ab.
             """,
@@ -896,6 +916,7 @@ class TestIosAclsModule(TestIosModule):
                                         sequence="30",
                                         source=dict(
                                             object_group="test_network_og",
+                                            any=True,
                                         ),
                                         destination=dict(any=True),
                                         dscp="ef",
@@ -952,6 +973,7 @@ class TestIosAclsModule(TestIosModule):
             "remark ipv6 remarks one",
             "remark ipv6 remarks test 2",
         ]
+
         self.assertEqual(sorted(result["commands"]), sorted(commands))
 
     def test_ios_acls_overridden_option(self):
