@@ -221,7 +221,8 @@ class TestMyModule(unittest.TestCase):
         expected_json = {'name': 'san_appli', 'svm': {'name': 'ansible'}, 'smart_container': True,
                          'san': {'application_components':
                                  [{'name': 'lun_name', 'lun_count': 1, 'total_size': 5368709120, 'tiering': {'control': 'required'}}]}}
-        expected_call = call('POST', 'application/applications', {'return_timeout': 30, 'return_records': 'true'}, json=expected_json, headers=None)
+        expected_call = call(
+            'POST', 'application/applications', {'return_timeout': 30, 'return_records': 'true'}, json=expected_json, headers=None, files=None)
         assert expected_call in mock_request.mock_calls
 
     @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.OntapRestAPI.send_request')
@@ -555,7 +556,8 @@ class TestMyModule(unittest.TestCase):
         expected_json = {'name': 'san_appli', 'svm': {'name': 'ansible'}, 'smart_container': True,
                          'san': {'application_components':
                                  [{'name': 'lun_name'}]}}
-        expected_call = call('POST', 'application/applications', {'return_timeout': 30, 'return_records': 'true'}, json=expected_json, headers=None)
+        expected_call = call(
+            'POST', 'application/applications', {'return_timeout': 30, 'return_records': 'true'}, json=expected_json, headers=None, files=None)
         assert expected_call in mock_request.mock_calls
 
     @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.OntapRestAPI.send_request')
