@@ -62,6 +62,7 @@ def sm_rest_info(state, healthy, transfer_state=None, destination_path=DEFAULT_A
             record['transfer']['uuid'] = 'xfer_uuid'
     if healthy is False:
         record['unhealthy_reason'] = 'this is why the relationship is not healthy.'
+    record['transfer_schedule'] = {'name': 'abc'}
 
     return {
         'records': [record],
@@ -217,8 +218,6 @@ def test_module_fail_unsuuported_rest_options():
 
 if netapp_utils.has_netapp_lib():
     zapi_create_responses = [
-        ('ZAPI', 'vserver-get-iter', ZRR['volume_info']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['no_records']),     # ONTAP to ONTAP
         ('ZAPI', 'snapmirror-create', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),
@@ -237,8 +236,6 @@ def test_successful_create_with_source(dont_sleep):
     responses = list(zapi_create_responses)
     responses.extend([
         # idempotency
-        ('ZAPI', 'vserver-get-iter', ZRR['volume_info']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),                # ONTAP to ONTAP
         ('ZAPI', 'vserver-peer-get-iter', ZRR['vserver_peer_info']),    # validate source svm
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),                # ONTAP to ONTAP, check for update
@@ -275,8 +272,6 @@ def test_successful_create_with_peer(dont_sleep):
 def test_negative_break(dont_sleep):
     ''' breaking snapmirror to test quiesce time-delay failure '''
     register_responses([
-        ('ZAPI', 'vserver-get-iter', ZRR['volume_info']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),
         ('ZAPI', 'vserver-peer-get-iter', ZRR['vserver_peer_info']),    # validate source svm
         ('ZAPI', 'snapmirror-quiesce', ZRR['success']),
@@ -300,8 +295,6 @@ def test_negative_break(dont_sleep):
 def test_successful_break(dont_sleep):
     ''' breaking snapmirror and testing idempotency '''
     register_responses([
-        ('ZAPI', 'vserver-get-iter', ZRR['volume_info']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),
         ('ZAPI', 'vserver-peer-get-iter', ZRR['vserver_peer_info']),    # validate source svm
         ('ZAPI', 'snapmirror-quiesce', ZRR['success']),
@@ -309,8 +302,6 @@ def test_successful_break(dont_sleep):
         ('ZAPI', 'snapmirror-break', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),                # check health
         # idempotency
-        ('ZAPI', 'vserver-get-iter', ZRR['volume_info']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info_broken_off']),
         ('ZAPI', 'vserver-peer-get-iter', ZRR['vserver_peer_info']),    # validate source svm
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),                # check health
@@ -328,14 +319,10 @@ def test_successful_break(dont_sleep):
 def test_successful_create_without_initialize():
     ''' creating snapmirror and testing idempotency '''
     register_responses([
-        ('ZAPI', 'vserver-get-iter', ZRR['volume_info']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['no_records']),             # ONTAP to ONTAP
         ('ZAPI', 'snapmirror-create', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),                # check health
         # idempotency
-        ('ZAPI', 'vserver-get-iter', ZRR['volume_info']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),                # ONTAP to ONTAP
         ('ZAPI', 'vserver-peer-get-iter', ZRR['vserver_peer_info']),    # validate source svm
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),                # ONTAP to ONTAP, check for update
@@ -389,8 +376,6 @@ def test_set_element_connection(mock_create_sf_cx):
 @patch('ansible_collections.netapp.ontap.plugins.modules.na_ontap_snapmirror.NetAppONTAPSnapmirror.set_element_connection')
 def test_successful_element_ontap_create(connection, dont_sleep):
     register_responses([
-        ('ZAPI', 'vserver-get-iter', ZRR['cserver']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['no_records']),             # element to ONTAP
         ('ZAPI', 'snapmirror-create', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),
@@ -398,8 +383,6 @@ def test_successful_element_ontap_create(connection, dont_sleep):
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),                # check status
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),                # check health
         # idempotency
-        ('ZAPI', 'vserver-get-iter', ZRR['volume_info']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info_snapmirrored_from_element']),      # element to ONTAP
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),                # element to ONTAP, check for update
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),                # check health
@@ -425,8 +408,6 @@ def test_successful_element_ontap_create(connection, dont_sleep):
 def test_successful_ontap_element_create(connection, dont_sleep):
     ''' check elementsw parameters for source '''
     register_responses([
-        ('ZAPI', 'vserver-get-iter', ZRR['volume_info']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),                # an existing relationship is required element to ONTAP
         ('ZAPI', 'snapmirror-get-iter', ZRR['no_records']),             # ONTAP to element
         ('ZAPI', 'snapmirror-create', ZRR['success']),
@@ -434,8 +415,6 @@ def test_successful_ontap_element_create(connection, dont_sleep):
         ('ZAPI', 'snapmirror-initialize', ZRR['sm_info']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),                # check status
         # idempotency
-        ('ZAPI', 'vserver-get-iter', ZRR['volume_info']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),                # an existing relationship is required element to ONTAP
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info_snapmirrored_to_element']),    # ONTAP to element
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),                # ONTAP to element, check for update
@@ -460,8 +439,6 @@ def test_successful_ontap_element_create(connection, dont_sleep):
 def test_successful_delete(dont_sleep):
     ''' deleting snapmirror and testing idempotency '''
     register_responses([
-        ('ZAPI', 'vserver-get-iter', ZRR['volume_info']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),
         ('ZAPI', 'vserver-peer-get-iter', ZRR['vserver_peer_info']),    # validate source svm
         ('ZAPI', 'snapmirror-quiesce', ZRR['success']),
@@ -472,8 +449,6 @@ def test_successful_delete(dont_sleep):
         ('ZAPI', 'snapmirror-destroy', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['no_records']),                # check health
         # idempotency
-        ('ZAPI', 'vserver-get-iter', ZRR['volume_info']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['no_records']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['no_records']),             # check health
     ])
@@ -490,8 +465,6 @@ def test_successful_delete(dont_sleep):
 def test_successful_delete_without_source_hostname_check(dont_sleep):
     ''' source cluster hostname is optional when source is unknown'''
     register_responses([
-        ('ZAPI', 'vserver-get-iter', ZRR['volume_info']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),
         ('ZAPI', 'vserver-peer-get-iter', ZRR['vserver_peer_info']),    # validate source svm
         ('ZAPI', 'snapmirror-quiesce', ZRR['success']),
@@ -511,8 +484,6 @@ def test_successful_delete_without_source_hostname_check(dont_sleep):
 def test_successful_delete_with_error_on_break(dont_sleep):
     ''' source cluster hostname is optional when source is unknown'''
     register_responses([
-        ('ZAPI', 'vserver-get-iter', ZRR['volume_info']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),
         ('ZAPI', 'snapmirror-quiesce', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info_snapmirrored_quiesced']),
@@ -534,8 +505,6 @@ def test_successful_delete_with_error_on_break(dont_sleep):
 def test_negative_delete_error_with_error_on_break(dont_sleep):
     ''' source cluster hostname is optional when source is unknown'''
     register_responses([
-        ('ZAPI', 'vserver-get-iter', ZRR['volume_info']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),
         ('ZAPI', 'snapmirror-quiesce', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info_snapmirrored_quiesced']),
@@ -555,8 +524,6 @@ def test_negative_delete_error_with_error_on_break(dont_sleep):
 def test_negative_delete_with_destination_path_missing():
     ''' with misisng destination_path'''
     register_responses([
-        ('ZAPI', 'vserver-get-iter', ZRR['volume_info']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
     ])
     args = dict(DEFAULT_ARGS)
     args.pop('destination_path')
@@ -605,15 +572,11 @@ def test_snapmirror_release():
 def test_snapmirror_resume():
     ''' resuming snapmirror '''
     register_responses([
-        ('ZAPI', 'vserver-get-iter', ZRR['volume_info']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info_snapmirrored_quiesced']),
         ('ZAPI', 'snapmirror-resume', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),    # update reads mirror_state
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),    # check health
         # idempotency test
-        ('ZAPI', 'vserver-get-iter', ZRR['volume_info']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info_snapmirrored']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),    # update reads mirror_state
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),    # check health
@@ -630,13 +593,9 @@ def test_snapmirror_resume():
 def test_snapmirror_restore():
     ''' restore snapmirror '''
     register_responses([
-        ('ZAPI', 'vserver-get-iter', ZRR['volume_info']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'snapmirror-restore', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),    # check health
         # idempotency test - TODO
-        ('ZAPI', 'vserver-get-iter', ZRR['volume_info']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'snapmirror-restore', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),    # check health
     ])
@@ -655,8 +614,6 @@ def test_snapmirror_restore():
 def test_successful_abort(dont_sleep):
     ''' aborting snapmirror and testing idempotency '''
     register_responses([
-        ('ZAPI', 'vserver-get-iter', ZRR['volume_info']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),
         ('ZAPI', 'snapmirror-quiesce', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info_snapmirrored_quiesced']),
@@ -664,8 +621,6 @@ def test_successful_abort(dont_sleep):
         ('ZAPI', 'snapmirror-destroy', ZRR['sm_info']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),    # check health
         # idempotency test
-        ('ZAPI', 'vserver-get-iter', ZRR['volume_info']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['no_records']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),    # check health
     ])
@@ -681,15 +636,11 @@ def test_successful_abort(dont_sleep):
 def test_successful_modify():
     ''' modifying snapmirror and testing idempotency '''
     register_responses([
-        ('ZAPI', 'vserver-get-iter', ZRR['volume_info']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),
         ('ZAPI', 'snapmirror-modify', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),    # update reads mirror_state
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),    # check health
         # idempotency test
-        ('ZAPI', 'vserver-get-iter', ZRR['volume_info']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),    # update reads mirror_state
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),    # check health
@@ -715,16 +666,12 @@ def test_successful_modify():
 def test_successful_initialize(dont_sleep):
     ''' initialize snapmirror and testing idempotency '''
     register_responses([
-        ('ZAPI', 'vserver-get-iter', ZRR['volume_info']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info_uninitialized']),
         ('ZAPI', 'snapmirror-initialize', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),    # check status
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),    # update reads mirror_state
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),    # check health
         # 2nd run
-        ('ZAPI', 'vserver-get-iter', ZRR['volume_info']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info_uninitialized_load_sharing']),
         ('ZAPI', 'snapmirror-initialize-ls-set', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),    # check status
@@ -748,15 +695,11 @@ def test_successful_initialize(dont_sleep):
 def test_successful_update():
     ''' update snapmirror and testing idempotency '''
     register_responses([
-        ('ZAPI', 'vserver-get-iter', ZRR['volume_info']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['error']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info_snapmirrored']),   # update reads mirror_state
         ('ZAPI', 'snapmirror-update', ZRR['success']),                  # update
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info']),                # check health
         # 2nd run
-        ('ZAPI', 'vserver-get-iter', ZRR['volume_info']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['error']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info_snapmirrored_load_sharing']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info_snapmirrored_load_sharing']),   # update reads mirror_state
         ('ZAPI', 'snapmirror-update-ls-set', ZRR['success']),           # update
@@ -780,8 +723,6 @@ def test_successful_update():
 def test_elementsw_no_source_path(connection):
     ''' elementsw_volume_exists '''
     register_responses([
-        ('ZAPI', 'vserver-get-iter', ZRR['volume_info']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['no_records']),
     ])
     mock_elem, mock_helper = Mock(), Mock()
@@ -979,18 +920,24 @@ def test_if_all_methods_catch_exception(dont_sleep):
 def test_successful_rest_create(dont_sleep):
     ''' creating snapmirror and testing idempotency '''
     register_responses([
-        ('GET', 'cluster', SRR['is_rest_9_8_0']),
+        ('GET', 'cluster', SRR['is_rest_9_11_1']),
         ('GET', 'snapmirror/relationships', SRR['zero_records']),
         ('POST', 'snapmirror/relationships', SRR['success']),
         ('GET', 'snapmirror/relationships', SRR['sm_get_uninitialized']),
         ('PATCH', 'snapmirror/relationships/b5ee4571-5429-11ec-9779-005056b39a06', SRR['success']),
         ('GET', 'snapmirror/relationships', SRR['sm_get_mirrored']),    # check initialized
         ('GET', 'snapmirror/relationships', SRR['sm_get_mirrored']),    # check health
+        ('GET', 'cluster', SRR['is_rest_9_11_1']),
+        ('GET', 'snapmirror/relationships', SRR['sm_get_mirrored']),
+        ('GET', 'snapmirror/relationships', SRR['sm_get_mirrored']),    # check health
     ])
     module_args = {
         "use_rest": "always",
+        "schedule": "abc"
     }
     assert call_main(my_main, DEFAULT_ARGS, module_args)['changed']
+    module_args['update'] = False
+    assert not call_main(my_main, DEFAULT_ARGS, module_args)['changed']
 
 
 def test_negative_rest_create():
@@ -1001,7 +948,21 @@ def test_negative_rest_create():
         "schedule": "abc",
         "relationship_type": "data_protection",
     }
-    msg = "REST API currently does not support 'identity_preserve, schedule, relationship_type: data_protection'"
+    msg = "REST API currently does not support 'identity_preserve, relationship_type: data_protection'"
+    assert create_module(my_module, DEFAULT_ARGS, module_args, fail=True)['msg'] == msg
+
+
+def test_negative_rest_create_schedule_not_supported():
+    ''' creating snapmirror with unsupported REST options '''
+    register_responses([
+        ('GET', 'cluster', SRR['is_rest_9_8_0']),
+    ])
+    module_args = {
+        "use_rest": "always",
+        "schedule": "abc",
+    }
+    msg = "Error: Minimum version of ONTAP for schedule is (9, 11, 1).  Current version: (9, 8, 0)."\
+          " - With REST use the policy option to define a schedule."
     assert create_module(my_module, DEFAULT_ARGS, module_args, fail=True)['msg'] == msg
 
 
@@ -1123,11 +1084,7 @@ def test_rest_sm_break_fails_if_uninit():
 def test_rest_sm_break_fails_if_load_sharing_or_vault():
     ''' testing snapmirror break fails for load_sharing or vault types '''
     register_responses([
-        ('ZAPI', 'vserver-get-iter', ZRR['volume_info']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info_snapmirrored_load_sharing']),
-        ('ZAPI', 'vserver-get-iter', ZRR['volume_info']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'snapmirror-get-iter', ZRR['sm_info_snapmirrored_vault']),
     ])
     module_args = {
@@ -1312,7 +1269,7 @@ def test_rest_snapmirror_delete_calls_abort(dont_sleep):
 def test_rest_snapmirror_modify():
     ''' snapmirror modify'''
     register_responses([
-        ('GET', 'cluster', SRR['is_rest_9_8_0']),
+        ('GET', 'cluster', SRR['is_rest_9_11_1']),
         ('GET', 'snapmirror/relationships', SRR['sm_get_mirrored']),  # apply first sm_get
         ('PATCH', 'snapmirror/relationships/b5ee4571-5429-11ec-9779-005056b39a06', SRR['success']),             # sm modify response
         ('GET', 'snapmirror/relationships', SRR['sm_get_mirrored']),  # sm update calls sm_get to check mirror state
@@ -1322,10 +1279,28 @@ def test_rest_snapmirror_modify():
     module_args = {
         "use_rest": "always",
         "policy": "Asynchronous",
+        "schedule": "abcdef",
     }
     assert call_main(my_main, DEFAULT_ARGS, module_args)['changed']
 
 
+def test_rest_snapmirror_modify_warning():
+    register_responses([
+        ('GET', 'cluster', SRR['is_rest_9_11_1']),
+        ('GET', 'snapmirror/relationships', SRR['sm_get_mirrored']),  # apply first sm_get
+        ('PATCH', 'snapmirror/relationships/b5ee4571-5429-11ec-9779-005056b39a06', SRR['success']),             # sm modify response
+    ])
+    module_args = {
+        "use_rest": "always",
+        "policy": "Asynchronous",
+        "schedule": "abcdef",
+    }
+    my_obj = create_module(my_module, DEFAULT_ARGS, module_args)
+    assert my_obj.snapmirror_mod_init_resync_break_quiesce_resume_rest(modify=module_args) is None
+    print_warnings()
+    assert_warning_was_raised('Unexpected key in modify: use_rest, value: always')
+
+
 def test_rest_snapmirror_restore():
     ''' snapmirror restore '''
     register_responses([
